package com.huiju.welcome.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.SysUser;
import com.huiju.welcome.model.TaPerson;
import com.huiju.welcome.model.TaWechatUser;
import com.huiju.welcome.service.ISysUserService;
import com.huiju.welcome.service.ITaPersonService;
import com.huiju.welcome.service.ITaWechatUserService;
import com.huiju.welcome.utils.CommConstant;
import com.huiju.welcome.utils.JWTUtils;
import com.huiju.welcome.utils.MiniApp;
import com.huiju.welcome.utils.StatusUtils;
import org.apache.http.HttpStatus;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-06-11
 */
@RestController
@RequestMapping("/miniapp")
public class TaWechatUserController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaWechatUserController.class);

    @Autowired
    private MiniApp miniApp;

    @Autowired
    private ITaWechatUserService iTaWechatUserService;

    @Autowired
    private ITaPersonService iTaPersonService;

    @Autowired
    private ISysUserService iSysUserService;

    @GetMapping("/login")
    public ResponseBean login(@RequestParam String code) {
        ResponseBean resp = miniApp.getOpenid(code);
        if (resp.getCode() != 200) {
            return resp;
        }

        JSONObject data = (JSONObject) resp.getData();
        String openid = data.getString("openid");
        String sessionKey = data.getString("session_key");
        String unionId = data.getString("unionid");
        String appid = miniApp.getAppid();

        Map<String, Object> map = new HashMap<>();
        map.put("openid", openid);
        map.put("sessionKey", sessionKey);
        map.put("unionId", unionId);
        map.put("appid", appid);

        // 如果已经存在的用户, 直接返回
        TaWechatUser taWechatUser = iTaWechatUserService.getByOpenid(openid, appid);
        if (null == taWechatUser) {
            // 否则新增用户数据
            taWechatUser = new TaWechatUser();
            taWechatUser.setAppid(appid);
            taWechatUser.setClientType(CommConstant.WECHAT_CLIENT_MINIAPP);
            taWechatUser.setOpenid(openid);
            taWechatUser.setUnionId(unionId);
            taWechatUser.setStatus(StatusUtils.Normal);
            taWechatUser.setCreateDate(LocalDateTime.now());

            boolean success = iTaWechatUserService.save(taWechatUser);
            if (!success) {
                return ResponseBean.error("预存用户信息失败", HttpStatus.SC_INTERNAL_SERVER_ERROR);
            }
        } else if (StatusUtils.Delete == taWechatUser.getStatus()) {
            map.put("identity", "");
        } else if (null != taWechatUser.getPersonId()) {
            SysUser sysUser = iSysUserService.getById(taWechatUser.getPersonId());
            if (StatusUtils.Normal == sysUser.getStatus()) {
                map.put("identity", sysUser.getUserIdentity());
            }
        }

        map.put("user", taWechatUser);
        map.put("token", JWTUtils.newToken(taWechatUser.getUserId() + ""));
        return ResponseBean.success(map);
    }

    @PostMapping("/bind")
    public ResponseBean bind(@RequestBody String paramStr, HttpServletRequest request) {
        String userId = JWTUtils.getSubject(request);
        TaWechatUser taWechatUser = iTaWechatUserService.getById(Integer.valueOf(userId));

        if (null == taWechatUser) {
            return ResponseBean.error("数据异常, 请清空缓存后重新操作", HttpStatus.SC_INTERNAL_SERVER_ERROR);
        }

        if (null != taWechatUser.getPersonId()) {
            return ResponseBean.error("不支持人员重复绑定", HttpStatus.SC_BAD_REQUEST);
        }

        JSONObject params = JSONObject.parseObject(paramStr);
        if (null == params) {
            return ResponseBean.error("绑定参数为空或者非法", HttpStatus.SC_BAD_REQUEST);
        }

        String phone = params.getString("phone");
        String captcha = params.getString("captcha");

        if (null == phone || "".equals(phone.trim()) || null == captcha || "".equals(captcha.trim())) {
            return ResponseBean.error("绑定参数为空或者非法", HttpStatus.SC_BAD_REQUEST);
        }

        // todo
        // 先简单验证
        if (!"1234".equals(captcha)) {
            return ResponseBean.error("绑定参数为空或者非法", HttpStatus.SC_BAD_REQUEST);
        }

        SysUser sysUser = iSysUserService.getByPhone(phone);
        if (null == sysUser) {
            return ResponseBean.error("该手机号对应人员不存在", HttpStatus.SC_BAD_REQUEST);
        }

        taWechatUser.setPersonId(sysUser.getUserId());
        boolean success = iTaWechatUserService.updateById(taWechatUser);

        if (!success) {
            return ResponseBean.error("人员绑定失败", HttpStatus.SC_INTERNAL_SERVER_ERROR);
        }

        Map<String, Object> map = new HashMap<>();
        map.put("user", taWechatUser);
        map.put("identity", sysUser.getUserIdentity());

        return ResponseBean.success(map);
    }

    /**
     * 修改对象
     * @param taWechatUser 实体对象
     * @return
     */
    @RequestMapping(value="/user/{id}",method= RequestMethod.PUT)
    public ResponseBean update(@RequestBody TaWechatUser taWechatUser, @PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaWechatUserService.updateById(taWechatUser)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taWechatUserUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/user/{id}",method= RequestMethod.GET)
    public ResponseBean get(@PathVariable Integer id, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (id.intValue() == 0) {
                String userId = JWTUtils.getSubject(request);
                responseBean.addSuccess(iTaWechatUserService.getById(Integer.valueOf(userId)));
            } else {
                responseBean.addSuccess(iTaWechatUserService.getById(id));
            }
        }catch (Exception e){
            logger.error("taWechatUserGetByID -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 分页查询
     */
    @RequestMapping(value="/user",method= RequestMethod.GET)
    public ResponseBean list(
        @RequestParam(defaultValue = "1") int pageNumber,
        @RequestParam(defaultValue = "10") int pageSize
    ){
        ResponseBean responseBean = new ResponseBean();
        try {
            IPage<TaWechatUser> pg = new Page<>(pageNumber, pageSize);
            QueryWrapper<TaWechatUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaWechatUser> result = iTaWechatUserService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("taWechatUserList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
