package com.huiju.welcome.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.SysUserRole;
import com.huiju.welcome.model.TdGoodsType;
import com.huiju.welcome.service.ITdGoodsTypeService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;


/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-16
 */
@RestController
@RequestMapping("/")
public class TdGoodsTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdGoodsTypeController.class);

    @Autowired
    public ITdGoodsTypeService iTdGoodsTypeService;


    /**
     * 保存对象
     * @param tdGoodsType 实体对象
     * @return
     */
    @RequestMapping(value="/tdGoodsType/add",method= RequestMethod.POST)
    public ResponseBean tpShopImgAdd(@RequestBody TdGoodsType tdGoodsType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdGoodsTypeService.save(tdGoodsType)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdGoodsTypeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/tdGoodsType/delete/{id}", method= RequestMethod.DELETE)
    public ResponseBean tdGoodsTypeDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTdGoodsTypeService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdGoodsTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param tdGoodsType 实体对象
     * @return
     */
    @RequestMapping(value="/tdGoodsType/update",method= RequestMethod.PUT)
    public ResponseBean tpShopImgUpdate(@RequestBody TdGoodsType tdGoodsType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdGoodsTypeService.updateById(tdGoodsType)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdGoodsTypeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdGoodsType/get/{id}",method= RequestMethod.GET)
    public ResponseBean tpShopImgGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTdGoodsTypeService.getById(id));
        }catch (Exception e){
            logger.error("tdGoodsTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    @ApiOperation(value = "商品类型列表", notes = "商品类型列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "typeName", value = "商品类型名称")
    })
    @RequestMapping(value = "/tdGoodsType", method = RequestMethod.GET)
    public ResponseBean typeList(@RequestParam(defaultValue = "1") int pageNum,
                                       @RequestParam(defaultValue = "10") int pageSize,
                                       @RequestParam(value = "typeName",required = false) String typeName) {
        IPage<TdGoodsType> pg = new Page<>(pageNum, pageSize);

        ResponseBean userManagement= iTdGoodsTypeService.typeList(pg,typeName);

        return userManagement;
    }
}
